@@ -15,9 +15,9 @@ class CNC:
 
     def __init__(self, framework):
         self.framework = framework
-        self.status = Status(self.framework)
-        self.command = Command(self.framework)
-        self.error = Error(self.framework)
+        self.status = Status(self)
+        self.command = Command(self)
+        self.error = Error(self)
 
     def start(self):
         linuxcnc_pid = subprocess.Popen(["pidof", "-x", "linuxcnc"], stdout=subprocess.PIPE)
@@ -46,7 +46,6 @@ class CNC:
 
             if message["command"] == "desktop:control:device:home":
                 if len(self.framework.machine.axis) > 0:
-                    print("1--->", len(self.framework.machine.axis))
                     self.command.set_teleop_enable(0)
                     if message["data"] == "all":
                         # 优先Z轴回零
@@ -57,7 +56,6 @@ class CNC:
                             self.command.home_axis(x)
                     else:
                         value = int(message["data"])
-                        print("2--->", value)
                         self.command.set_teleop_enable_mode(0)
                         self.command.home_axis(value)
 
